# commitlint-config-cz 

[![npm][npm-image]][npm-url]
[![Build Status][travis-image]][travis-url]
[![Build status][appveyor-image]][appveyor-url]
[![Coverage Status][coveralls-image]][coveralls-url]

[commitlint][] sharable configuration files, which also includes modules & API
for config conversion.

If `.cz-config.js` that is for [@whizark/cz-cli][] or
[cz-customizable][] exists in your package root directory, its
`{types,scopes,scopeOverrides}` are merged with
`rules.{type-enum,scope-enum}`.

## Installation

Install `commitlint-config-cz` as a local dependency.

```sh
npm install commitlint-config-cz --save-dev
```

## Usage

Extend `commitlint-config-cz` in `commitlint.config.js`.

```js
module.exports = {
    extends: [
        'other-config',
        'cz'
    ]
};
```

## Modules & API

There are some modules and API to convert `cz-customizable`'s config into `commitlint`'s config.

### `config.js`

Gets the `commitlint` config from the `.cz-config.js` in the package root.

```js
const config = require('commitlint-config-cz/lib/config')();
````

#### `get(pathOrCzConfig: string | Object, defaultConfig?: Object): Object`

Gets the `commitlint` config from a `cz-customizable` config.

```js
const getConfig = require('commitlint-config-cz/lib/config').get;

// From a path.
const config = getConfig('path/to/.cz-config.js');
````

```js
const getConfig = require('commitlint-config-cz/lib/config').get;
const czConfig  = { /* `cz-customizable` config object. */ };

// From a `cz-customizable` config object.
const config = getConfig(czConfig);
````

```js
const getConfig     = require('commitlint-config-cz/lib/config').get;
const czConfig      = { /* `cz-customizable` config object. */ };
const defaultConfig = {  // The default `commitlint` config.
    rules: {
        'scope-enum': [  // rule
            2,           // [1] level
            'always',    // [2] applicability
            [],          // [3] value
        ],
        'type-enum' : [  // rule
            2,           // [1] level
            'always',    // [2] applicability
            [],          // [3] value
        ],
    },
};

// Converts and merges the `cz-customizable` config with the default `commitlint` config.
const config = getConfig(czConfig, defaultConfig);
````

1. If `cz-customizable` config has `scopes`, `scopeOverrides` or `types` field,
   the value(s) [3] of the default `commitlint` config is/are **REPLACED** by converted value(s).  
   Level [1] and applicability [2] remain as they are.
2. `scope-enum` rule or/and `type-enum` rule is/are completely **REMOVED**, if its value is an empty array.

---

### `cz-config.js`

Gets the `.cz-config.js` as an object in the package root.

```js
const czConfig = require('commitlint-config-cz/lib/cz-config')();
````

#### `get(path: string): Object`

Gets the `cz-customizable` config object from a path.

```js
const getCzConfig = require('commitlint-config-cz/lib/cz-config').get;

const czConfig = getCzConfig('path/to/.cz-config.js');
````

---

### `scopes.js`

Gets the `value` for [scope-enum][] rule from the `.cz-config.js` in the package root.

```js
const scopes = require('commitlint-config-cz/lib/scopes')();
````

#### `get(czConfig: Object): string[]`

Gets the `value` for [scope-enum][] rule from a `cz-customizable` config object.

```js
const getScopes = require('commitlint-config-cz/lib/scopes').get;
const czConfig  = { /* `cz-customizable` config object. */ };

const scopes = getScopes(czConfig);
````

---

### `types.js`

Gets the `value` for [type-enum][] rule from the `.cz-config.js` in the package root.

```js
const types = require('commitlint-config-cz/lib/types')();
````

#### `get(czConfig: Object): string[]`

Gets the `value` for [type-enum][] rule from a `cz-customizable` config object.

```js
const getTypes = require('commitlint-config-cz/lib/types').get;
const czConfig = { /* `cz-customizable` config object. */ };

const types = getTypes(czConfig);
````

[commitlint]: https://github.com/marionebl/commitlint
[@whizark/cz-cli]: https://github.com/whizark/cz-cli
[cz-customizable]: https://github.com/leonardoanalista/cz-customizable

[npm-image]: https://img.shields.io/npm/v/commitlint-config-cz.svg
[npm-url]: https://www.npmjs.com/commitlint-config-cz

[coveralls-image]: https://coveralls.io/repos/whizark/commitlint-config-cz/badge.svg?branch=master&service=github
[coveralls-url]: https://coveralls.io/github/whizark/commitlint-config-cz?branch=master

[travis-image]: https://travis-ci.org/whizark/commitlint-config-cz.svg?branch=master
[travis-url]: https://travis-ci.org/whizark/commitlint-config-cz

[appveyor-image]: https://ci.appveyor.com/api/projects/status/github/whizark/commitlint-config-cz?branch=master&svg=true
[appveyor-url]: https://ci.appveyor.com/project/whizark/commitlint-config-cz/branch/master

[scope-enum]: http://marionebl.github.io/commitlint/#/reference-rules?id=scope-enum
[type-enum]: http://marionebl.github.io/commitlint/#/reference-rules?id=type-enum
